Zero-copy mesh format adapters for Bunny.
Structs
- Compressed
Mesh - A zero-allocation borrowed view over a validated Bunny compressed mesh payload.
- ObjMesh
- A borrowed OBJ mesh view over the original text input.
- ObjTriangles
- Forward iterator over decoded OBJ triangle face records.
- ObjVertex
- A text OBJ vertex decoded from a borrowed
vrecord. - ObjVertices
- Forward iterator over decoded OBJ vertex records.
- PlyBinary
Mesh - A borrowed binary PLY mesh with canonical
float x/y/zvertices and triangle faces. - PlyVertex
- A PLY vertex decoded from borrowed little-endian float bytes.
Enums
- Compressed
Index Width - Triangle index width used by a Bunny compressed mesh payload.
- Compressed
Mesh Error - Error returned when a Bunny compressed mesh byte stream is invalid.
- Compressed
Triangle - Decoded triangle from a Bunny compressed mesh payload.
- ObjError
- Error returned when an OBJ mesh cannot be parsed as the Bunny text profile.
- PlyError
- Error returned when a binary PLY mesh cannot be parsed as the Bunny mesh profile.
Functions
- decode_
compressed_ mesh - Decodes a canonical Bunny compressed mesh byte stream.
- parse_
binary_ ply - Parses a canonical binary little-endian PLY mesh as a zero-copy borrowed view.
- parse_
obj_ text - Parses a supported OBJ text mesh as a zero-copy borrowed view.