PlyBinaryMesh

Struct PlyBinaryMesh 

pub struct PlyBinaryMesh<'a> { /* private fields */ }
A borrowed binary PLY mesh with canonical float x/y/z vertices and triangle faces.

Implementations

Source

impl<'a> PlyBinaryMesh<'a>

pub const fn vertex_count(self) -> usize

Returns the number of vertices declared by the PLY file.

pub const fn face_count(self) -> usize

Returns the number of triangle faces declared by the PLY file.

pub const fn vertex_bytes(self) -> &'a [u8]

Returns the borrowed binary vertex payload.

pub const fn face_bytes(self) -> &'a [u8]

Returns the borrowed binary face payload.

pub fn vertex(self, index: usize) -> Result<PlyVertex, PlyError>

Reads a vertex from the borrowed payload.

Errors

Returns PlyError::PayloadTooShort if the requested vertex is out of range.

pub fn triangle(self, index: usize) -> Result<Triangle32, PlyError>

Reads a triangle face from the borrowed payload.

Errors

Returns a PlyError if the face is out of range, is not triangular, or contains negative signed PLY indices.