Crate bunny_codec

Crate bunny_codec 

Zero-copy mesh format adapters for Bunny.

Structs

CompressedMesh
A zero-allocation borrowed view over a validated Bunny compressed mesh payload.
ObjMesh
A borrowed OBJ mesh view over the original text input.
ObjTriangles
Forward iterator over decoded OBJ triangle face records.
ObjVertex
A text OBJ vertex decoded from a borrowed v record.
ObjVertices
Forward iterator over decoded OBJ vertex records.
PlyBinaryMesh
A borrowed binary PLY mesh with canonical float x/y/z vertices and triangle faces.
PlyVertex
A PLY vertex decoded from borrowed little-endian float bytes.

Enums

CompressedIndexWidth
Triangle index width used by a Bunny compressed mesh payload.
CompressedMeshError
Error returned when a Bunny compressed mesh byte stream is invalid.
CompressedTriangle
Decoded triangle from a Bunny compressed mesh payload.
ObjError
Error returned when an OBJ mesh cannot be parsed as the Bunny text profile.
PlyError
Error returned when a binary PLY mesh cannot be parsed as the Bunny mesh profile.

Functions

decode_compressed_mesh
Decodes a canonical Bunny compressed mesh byte stream.
parse_binary_ply
Parses a canonical binary little-endian PLY mesh as a zero-copy borrowed view.
parse_obj_text
Parses a supported OBJ text mesh as a zero-copy borrowed view.