pub fn parse_binary_ply(input: &[u8]) -> Result<PlyBinaryMesh<'_>, PlyError>Expand description
Parses a canonical binary little-endian PLY mesh as a zero-copy borrowed view.
The accepted profile is float x, float y, float z vertices and
property list uchar int vertex_indices triangle faces.
Errors
Returns PlyError when the header or binary payload does not match the
canonical Bunny mesh PLY profile.