pub struct PlyBinaryMesh<'a> { /* private fields */ }Expand description
A borrowed binary PLY mesh with canonical float x/y/z vertices and triangle faces.
Implementations
Sourceimpl<'a> PlyBinaryMesh<'a>
impl<'a> PlyBinaryMesh<'a>
Sourcepub const fn vertex_count(self) -> usize
pub const fn vertex_count(self) -> usize
Returns the number of vertices declared by the PLY file.
Sourcepub const fn face_count(self) -> usize
pub const fn face_count(self) -> usize
Returns the number of triangle faces declared by the PLY file.
Sourcepub const fn vertex_bytes(self) -> &'a [u8] ⓘ
pub const fn vertex_bytes(self) -> &'a [u8] ⓘ
Returns the borrowed binary vertex payload.
Sourcepub const fn face_bytes(self) -> &'a [u8] ⓘ
pub const fn face_bytes(self) -> &'a [u8] ⓘ
Returns the borrowed binary face payload.